// This is an include point for the implementations of the rlang
// library. It should be included in a single and separate compilation
// unit.

#include "lib/rlang.h"

#include "lib/attrs.c"
#include "lib/cnd.c"
#include "lib/debug.c"
#include "lib/env.c"
#include "lib/env-binding.c"
#include "lib/eval.c"
#include "lib/export.c"
#include "lib/fn.c"
#include "lib/formula.c"
#include "lib/lang.c"
#include "lib/node.c"
#include "lib/parse.c"
#include "lib/quo.c"
#include "lib/replace-na.c"
#include "lib/rlang.c"
#include "lib/session.c"
#include "lib/sexp.c"
#include "lib/squash.c"
#include "lib/stack.c"
#include "lib/sym.c"
#include "lib/sym-unescape.c"
#include "lib/vec.c"
#include "lib/vec-chr.c"
#include "lib/vec-lgl.c"
#include "lib/vec-list.c"
#include "lib/weakref.c"
